@@ -4,7 +4,7 @@ vector<string>::const_iterator ConfigFile::find(string const &target) const
 {
     return find_if(
                 begin(), end(), 
-                [&, d_caseSensitive](string const &haystack)
+                [&](string const &haystack)
                 {
                     return (d_caseSensitive ? finder : casefinder)
                                 (haystack, target);
